diff --git a/typo3/sysext/backend/Classes/Clipboard/Clipboard.php b/typo3/sysext/backend/Classes/Clipboard/Clipboard.php
index 5d83e015c529b70379a5b004cdcf89bebb50b4a3..dbe48ef0fb0bd514b1beb26d54daba9b9a16b34b 100644
--- a/typo3/sysext/backend/Classes/Clipboard/Clipboard.php
+++ b/typo3/sysext/backend/Classes/Clipboard/Clipboard.php
@@ -924,13 +924,8 @@ class Clipboard
         return is_array($this->clipData[$this->current]['el']) && !empty($this->clipData[$this->current]['el']);
     }
 
-    /*****************************************
-     *
-     * FOR USE IN tce_db.php:
-     *
-     ****************************************/
     /**
-     * Applies the proper paste configuration in the $cmd array send to tce_db.php.
+     * Applies the proper paste configuration in the $cmd array send to SimpleDataHandlerController (tce_db route)
      * $ref is the target, see description below.
      * The current pad is pasted
      *
diff --git a/typo3/sysext/backend/Configuration/Backend/Routes.php b/typo3/sysext/backend/Configuration/Backend/Routes.php
index c75b7d8e513254c47b40b9418c8750af6af8f7db..2dd6c3a55256d01c0b813d8adf1a0ce5f4744307 100644
--- a/typo3/sysext/backend/Configuration/Backend/Routes.php
+++ b/typo3/sysext/backend/Configuration/Backend/Routes.php
@@ -189,7 +189,7 @@ return [
 
     /**
      * Gateway for TCE (TYPO3 Core Engine) file-handling through POST forms.
-     * This script serves as the fileadministration part of the TYPO3 Core Engine.
+     * This script serves as the file administration part of the TYPO3 Core Engine.
      * Basically it includes two libraries which are used to manipulate files on the server.
      *
      * For syntax and API information, see the document 'TYPO3 Core APIs'
diff --git a/typo3/sysext/backend/Resources/Private/TypeScript/AjaxDataHandler.ts b/typo3/sysext/backend/Resources/Private/TypeScript/AjaxDataHandler.ts
index 1dc40dd5170504312832894259206bd0fe963492..d33cec7c424dc49da42fb63b838305f37b28a667 100644
--- a/typo3/sysext/backend/Resources/Private/TypeScript/AjaxDataHandler.ts
+++ b/typo3/sysext/backend/Resources/Private/TypeScript/AjaxDataHandler.ts
@@ -28,7 +28,8 @@ enum Identifiers {
 
 /**
  * Module: TYPO3/CMS/Backend/AjaxDataHandler
- * AjaxDataHandler - Javascript functions to work with AJAX and interacting with tce_db.php
+ * Javascript functions to work with AJAX and interacting with Datahandler
+ * through \TYPO3\CMS\Backend\Controller\SimpleDataHandlerController->processAjaxRequest (record_process route)
  */
 class AjaxDataHandler {
   /**
@@ -234,7 +235,7 @@ class AjaxDataHandler {
   }
 
   /**
-   * AJAX call to tce_db.php
+   * AJAX call to record_process route (SimpleDataHandlerController->processAjaxRequest)
    * returns a jQuery Promise to work with
    *
    * @param {Object} params
diff --git a/typo3/sysext/core/Classes/DataHandling/DataHandler.php b/typo3/sysext/core/Classes/DataHandling/DataHandler.php
index 93d8ae688663eff3a1526da9f6173a4592b40ddc..11537a2da0e06a694b03c9b97bfaafc4e95b9ae1 100644
--- a/typo3/sysext/core/Classes/DataHandling/DataHandler.php
+++ b/typo3/sysext/core/Classes/DataHandling/DataHandler.php
@@ -66,13 +66,13 @@ use TYPO3\CMS\Core\Versioning\VersionState;
  * This class was formerly known as TCEmain.
  *
  * This is the TYPO3 Core Engine class for manipulation of the database
- * This class is used by eg. the tce_db.php script which provides an the interface for POST forms to this class.
+ * This class is used by eg. the tce_db BE route (SimpleDataHandlerController) which provides an the interface for POST forms to this class.
  *
  * Dependencies:
  * - $GLOBALS['TCA'] must exist
  * - $GLOBALS['LANG'] must exist
  *
- * tce_db.php for further comments and SYNTAX! Also see document 'TYPO3 Core API' for details.
+ * Also see document 'TYPO3 Core API' for details.
  */
 class DataHandler implements LoggerAwareInterface
 {
@@ -8699,7 +8699,7 @@ class DataHandler implements LoggerAwareInterface
         if (!$this->enableLogging) {
             return 0;
         }
-        // Type value for tce_db.php
+        // Type value for DataHandler
         $type = 1;
         if (!$this->storeLogMessages) {
             $details = '';
diff --git a/typo3/sysext/beuser/Classes/ViewHelpers/IssueCommandViewHelper.php b/typo3/sysext/beuser/Classes/ViewHelpers/IssueCommandViewHelper.php
index 31cf3ebabe0783bb9866bee20285b8f44c0d82cd..c677911470746e1ddfcf1290cb7387f827e4d3ee 100644
--- a/typo3/sysext/beuser/Classes/ViewHelpers/IssueCommandViewHelper.php
+++ b/typo3/sysext/beuser/Classes/ViewHelpers/IssueCommandViewHelper.php
@@ -32,18 +32,18 @@ class IssueCommandViewHelper extends AbstractViewHelper
      */
     public function initializeArguments()
     {
-        $this->registerArgument('parameters', 'string', 'Is a set of GET params to send to tce_db.php. Example: "&cmd[tt_content][123][move]=456" or "&data[tt_content][123][hidden]=1&data[tt_content][123][title]=Hello%20World', true);
+        $this->registerArgument('parameters', 'string', 'Is a set of GET params to send to route tce_db (SimpleDataHandlerController). Example: "&cmd[tt_content][123][move]=456" or "&data[tt_content][123][hidden]=1&data[tt_content][123][title]=Hello%20World', true);
         $this->registerArgument('redirectUrl', 'string', 'Redirect URL if any other that \TYPO3\CMS\Core\Utility\GeneralUtility::getIndpEnv(\'REQUEST_URI\') is preferred', false, '');
     }
 
     /**
      * Returns a URL with a command to TYPO3 Core Engine (tce_db.php)
      *
      * @param array $arguments
      * @param \Closure $renderChildrenClosure
      * @param RenderingContextInterface $renderingContext
      *
-     * @return string URL to tce_db.php + parameters
+     * @return string URL to tce_db + parameters
      * @see \TYPO3\CMS\Backend\Utility\BackendUtility::getLinkToDataHandlerAction()
      */
     public static function renderStatic(array $arguments, \Closure $renderChildrenClosure, RenderingContextInterface $renderingContext)
@@ -32,18 +32,18 @@ class IssueCommandViewHelper extends AbstractViewHelper
 
     /**
-     * Returns a URL with a command to TYPO3 Core Engine (tce_db.php)
+     * Returns a URL with a command to TYPO3 Core Engine - DataHandler (route tce_db)
      *
      * @param array $arguments